using System;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Windows;

namespace Miche.Mvvm
{
	public partial class MainWindow : Window, INotifyPropertyChanged
	{
		/// <summary>
		/// Cognome
		/// </summary>
		private string mCognome;

		/// <summary>
		/// Eta
		/// </summary>
		private string mEta;

		/// <summary>
		/// Testo1
		/// </summary>
		private string mNome;

		/// <summary>
		/// Textbox risultati x mostrare come funziona la gestione Data Driven
		/// </summary>
		private string mResultText;

		/// <summary>
		/// Utente selezionato sulla Listview
		/// </summary>
		private Utente mSelectedUtente;

		/// <summary>
		/// Utenti
		/// </summary>
		private ObservableCollection<Utente> mUtenti;

		/// <summary>
		/// Occurs when a property value changes.
		/// </summary>
		public event PropertyChangedEventHandler PropertyChanged;

		public MainWindow()
		{
			InitializeComponent();
			DataContext = this;
			Utenti = new ObservableCollection<Utente>();
			InitUtenti();
		}

		/// <summary>
		/// Cognome
		/// </summary>
		public string Cognome
		{
			get
			{
				return mCognome;
			}
			set
			{
				mCognome = value;
				OnPropertyChanged(nameof(Cognome));
				UpdateResultTextFromTextBoxes();
			}
		}

		/// <summary>
		/// Eta
		/// </summary>
		public string Eta
		{
			get
			{
				return mEta;
			}
			set
			{
				mEta = value;
				OnPropertyChanged(nameof(Eta));
				UpdateResultTextFromTextBoxes();
			}
		}

		/// <summary>
		/// Testo1
		/// </summary>
		public string Nome
		{
			get
			{
				return mNome;
			}
			set
			{
				mNome = value;
				OnPropertyChanged(nameof(Nome));
				UpdateResultTextFromTextBoxes();
			}
		}
		/// <summary>
		/// Textbox risultati x mostrare come funziona la gestione Data Driven
		/// </summary>
		public string ResultText
		{
			get
			{
				return mResultText;
			}
			set
			{
				mResultText = value;
				OnPropertyChanged(nameof(ResultText));
			}
		}
		/// <summary>
		/// Utente selezionato sulla Listview
		/// </summary>
		public Utente SelectedUtente
		{
			get
			{
				return mSelectedUtente;
			}
			set
			{
				mSelectedUtente = value;
				OnPropertyChanged(nameof(SelectedUtente));
				UpdateResultTextFromList();
			}
		}

		





		/// <summary>
		/// Utenti
		/// </summary>
		public ObservableCollection<Utente> Utenti
		{
			get
			{
				return mUtenti;
			}
			set
			{
				mUtenti = value;
				OnPropertyChanged(nameof(Utenti));
			}
		}

		public void InitUtenti()
		{
			Utenti.Add(new Utente() { Nome = "Bill", Cognome = "Gates", Eta = "40" });
			Utenti.Add(new Utente() { Nome = "Ada", Cognome = "Lovelace", Eta = "30" });
			Utenti.Add(new Utente() { Nome = "Steve", Cognome = "Wozniak", Eta = "40" });
			Utenti.Add(new Utente() { Nome = "Grace", Cognome = "Hopper", Eta = "30" });
			Utenti.Add(new Utente() { Nome = "Dennis", Cognome = "Ritchie", Eta = "35" });
			Utenti.Add(new Utente() { Nome = "Margaret", Cognome = "Hamilton", Eta = "36" });
			Utenti.Add(new Utente() { Nome = "Charles", Cognome = "Babbage", Eta = "37" });
			Utenti.Add(new Utente() { Nome = "Jack", Cognome = "Kilby", Eta = "38" });
			Utenti.Add(new Utente() { Nome = "Pier Giorgio", Cognome = "Perotto", Eta = "39" });
			Utenti.Add(new Utente() { Nome = "Walter", Cognome = "Brattain", Eta = "40" });
			Utenti.Add(new Utente() { Nome = "Buzz", Cognome = "Aldrin", Eta = "30" });
			Utenti.Add(new Utente() { Nome = "George", Cognome = "Bool", Eta = "35" });
			Utenti.Add(new Utente() { Nome = "Nolan", Cognome = "Bushnell", Eta = "36" });
			Utenti.Add(new Utente() { Nome = "Shigeru", Cognome = "Miyamoto", Eta = "37" });
			Utenti.Add(new Utente() { Nome = "Geoff", Cognome = "Crammond", Eta = "38" });
			Utenti.Add(new Utente() { Nome = "Chuck", Cognome = "Peddle", Eta = "39" });
			Utenti.Add(new Utente() { Nome = "Yoshihisa", Cognome = "Maitani", Eta = "40" });
			Utenti.Add(new Utente() { Nome = "Steve", Cognome = "Russell", Eta = "35" });
			Utenti.Add(new Utente() { Nome = "Giacomo Augusto", Cognome = "Pignone", Eta = "40" });
			Utenti.Add(new Utente() { Nome = "Harry", Cognome = "Ricardo", Eta = "35" });
		}

		/// <summary>
		/// Called when [property changed].
		/// </summary>
		/// <param name="propertyName">Name of the property.</param>
		protected virtual void OnPropertyChanged(string propertyName)
		{
			if (PropertyChanged != null)
				PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
		}

		private void Add_Click(object sender, RoutedEventArgs e)
		{
			Utente u = new Utente();
			u.Nome = Nome;
			u.Cognome = Cognome;
			u.Eta = Eta;
			Utenti.Add(u);
		}

		private void UpdateResultTextFromList()
		{
			ResultText = string.Format("Dalla Lista: {0} {1} {2}", SelectedUtente.Cognome, SelectedUtente.Nome, SelectedUtente.Eta);
		}

		private void UpdateResultTextFromTextBoxes()
		{
			ResultText = string.Format("Dalle Property: {0} {1} {2}", Cognome, Nome, Eta);
		}
	}
}